__version__="4.4.0"
__copyright__="Copyright (c) 2001 - 2022 The SCons Foundation"
__developer__="_reproducible"
__date__="Sun, 07 Aug 2022 13:52:56 +0200"
__buildsys__="_reproducible"
__revision__=""
__build__=""
# make sure compatibility is always in place
import SCons.compat # noqa